# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['sortedness', 'sortedness.evaluation', 'sortedness.wtau']

package_data = \
{'': ['*']}

install_requires = \
['lange>=1.230203.1,<2.0.0',
 'pathos>=0.3.0,<0.4.0',
 'shelchemy>=0.220906.5,<0.220907.0']

extras_require = \
{':python_version >= "3.8" and python_version < "3.11"': ['scipy>=1.10.1,<2.0.0']}

setup_kwargs = {
    'name': 'sortedness',
    'version': '0.230501.8',
    'description': 'Measures of projection quality',
    'long_description': '![test](https://github.com/sortedness/sortedness/workflows/test/badge.svg)\n[![codecov](https://codecov.io/gh/sortedness/sortedness/branch/main/graph/badge.svg)](https://codecov.io/gh/sortedness/sortedness)\n<a href="https://pypi.org/project/sortedness">\n<img src="https://img.shields.io/github/v/release/sortedness/sortedness?display_name=tag&sort=semver&color=blue" alt="github">\n</a>\n![Python version](https://img.shields.io/badge/python-3.8%20%7C%203.9-blue.svg)\n[![license: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)\n\n<!--- [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.5501845.svg)](https://doi.org/10.5281/zenodo.5501845)\n[![arXiv](https://img.shields.io/badge/arXiv-2109.06028-b31b1b.svg?style=flat-square)](https://arxiv.org/abs/2109.06028) --->\n[![API documentation](https://img.shields.io/badge/doc-API%20%28auto%29-a0a0a0.svg)](https://sortedness.github.io/sortedness)\n[![Downloads](https://static.pepy.tech/badge/sortedness)](https://pepy.tech/project/sortedness)\n\n# sortedness\n\n\n\n`sortedness` is a measure of quality of data transformation, often dimensionality reduction.\nIt is less sensitive to irrelevant distortions and return values in a more meaningful interval than Kruskal stress formula I.\n<br>This [Python library](https://pypi.org/project/sortedness) / [code](https://github.com/sortedness/sortedness) provides a reference implementation for the stress function presented [here (link broken until the paper is published)](https://arxiv.org/abs/2109.06028.9999).\n\n## Overview\n\n## Python installation\n### from package through pip\n```bash\n# Set up a virtualenv. \npython3 -m venv venv\nsource venv/bin/activate\n\n# Install from PyPI\npip install -U sortedness\n```\n\n### from source\n```bash\ngit clone https://github.com/sortedness/sortedness\ncd sortedness\npoetry install\n```\n\n\n### Examples\n\n**Sortedness**\n<details>\n<p>\n\n```python3\n\nimport numpy as np\nfrom numpy.random import permutation\nfrom sklearn.decomposition import PCA\n\nfrom sortedness.local import sortedness\n\nmean = (1, 2)\ncov = np.eye(2)\nrng = np.random.default_rng(seed=0)\noriginal = rng.multivariate_normal(mean, cov, size=12)\nprojected2 = PCA(n_components=2).fit_transform(original)\nprojected1 = PCA(n_components=1).fit_transform(original)\nnp.random.seed(0)\nprojectedrnd = permutation(original)\n\ns = sortedness(original, original)\nprint(min(s), max(s), s)\n"""\n1.0 1.0 [1. 1. 1. 1. 1. 1. 1. 1. 1. 1. 1. 1.]\n"""\n```\n\n```python3\n\ns = sortedness(original, projected2)\nprint(min(s), max(s), s)\n"""\n1.0 1.0 [1. 1. 1. 1. 1. 1. 1. 1. 1. 1. 1. 1.]\n"""\n```\n\n```python3\n\ns = sortedness(original, projected1)\nprint(min(s), max(s), s)\n"""\n0.432937128932 0.944810120534 [0.43293713 0.53333015 0.88412753 0.94481012 0.81485109 0.81330052\n 0.76691474 0.91169619 0.88998817 0.90102615 0.61372341 0.86996213]\n"""\n```\n\n```python3\n\ns = sortedness(original, projectedrnd)\n```\n\n\n</p>\n</details>\n\n**Pairwise sortedness**\n<details>\n<p>\n\n```python3\n\nimport numpy as np\nfrom numpy.random import permutation\nfrom sklearn.decomposition import PCA\n\nfrom sortedness.local import pwsortedness\n\nmean = (1, 2)\ncov = np.eye(2)\nrng = np.random.default_rng(seed=0)\noriginal = rng.multivariate_normal(mean, cov, size=12)\nprojected2 = PCA(n_components=2).fit_transform(original)\nprojected1 = PCA(n_components=1).fit_transform(original)\nnp.random.seed(0)\nprojectedrnd = permutation(original)\n\ns = pwsortedness(original, original)\nprint(min(s), max(s), s)\n"""\n1.0 1.0 [1. 1. 1. 1. 1. 1. 1. 1. 1. 1. 1. 1.]\n"""\n```\n\n```python3\n\ns = pwsortedness(original, projected2)\nprint(min(s), max(s), s)\n"""\n1.0 1.0 [1. 1. 1. 1. 1. 1. 1. 1. 1. 1. 1. 1.]\n"""\n```\n\n```python3\n\ns = pwsortedness(original, projected1)\nprint(min(s), max(s), s)\n"""\n0.730078995423 0.837310352695 [0.75892647 0.730079   0.83496865 0.73161226 0.75376525 0.83301104\n 0.76695755 0.74759156 0.81434161 0.74067221 0.74425225 0.83731035]\n"""\n```\n\n```python3\n\ns = pwsortedness(original, projectedrnd)\n```\n\n```python3\nprint(min(s), max(s), s)\n\n"""\n-0.198780473657 0.147224384381 [-0.19878047 -0.14125391  0.03276727 -0.092844   -0.0866695   0.14722438\n -0.07603536 -0.08916877 -0.1373848  -0.10933483 -0.07774488  0.05404383]\n"""\n```\n\n\n</p>\n</details>\n\n\n** Copyright (c) 2022. Davi Pereira dos Santos and Tacito Neves**\n\n\n\n\n\n## Grants\n',
    'author': 'davips',
    'author_email': 'dpsabc@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.10,<4.0',
}
from build import *
build(setup_kwargs)

setup(**setup_kwargs)
